/* 
**
**  remedial - a GUI front-end for avifile
**  Copyright (C) 2002  Paul Dwerryhouse <paul@dwerryhouse.com.au>
**
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License version 2, as 
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#include <qapplication.h>
#include <qvbox.h>
#include <qlabel.h>
#include <qpixmap.h>
#include <qevent.h>
#include <qpopupmenu.h>
#include <stdio.h>
#include <stdlib.h>
#include <qtimer.h>
#include "player.h"
#include "qtnewgui.h"
#include "qtnewgui.moc"
#include <remedialv2.xpm>
#include <numbers.xpm>

const char **numbers[] = {
    n0_xpm, n1_xpm, n2_xpm, n3_xpm, n4_xpm,
    n5_xpm, n6_xpm, n7_xpm, n8_xpm, n9_xpm,
};

QLabel *presetview;
QLabel *status;
QPopupMenu *menu;

QtNewGui::QtNewGui(QWidget * parent, const char *name)
:QVBox(parent, name)
{

    sig_start = playing = sig_stop = 0;
    page = 0;
    currentselection = -1;

    timer = new QTimer();

    setFixedSize(276, 129);
    setMouseTracking(1);

    QLabel *label = new QLabel(this);
    label->setPixmap(QPixmap(remedialv2_xpm));

    presetview = new QLabel(label);
    presetview->setPixmap(QPixmap(numbers[0]));
    presetview->setFixedSize(28, 33);
    presetview->move(30, 25);

    status = new QLabel(label);
    status->setFixedSize(171, 19);
    status->move(73, 21);
    status->setPaletteBackgroundColor(QColor(153, 232, 163));

    menu = new QPopupMenu(label);
    menu->insertItem("About", 0);
    menu->insertItem("Options", 1);
    menu->insertItem("Play", 2);
    menu->insertItem("Stop", 3);
    menu->insertItem("Reload Config", 4);
    menu->insertItem("Quit", 5);

    connect(menu, SIGNAL(activated(int)), this, SLOT(do_menu(int)));


    connect(timer, SIGNAL(timeout()), this, SLOT(timerslot()));

    timer->start(500);
}

void QtNewGui::mouseReleaseEvent(QMouseEvent * e)
{
    int x, y;

    x = e->x();
    y = e->y();

    if (e->button() == Qt::RightButton) {
	if (!menu->isVisible()) {
	    menu->move(e->globalX(), e->globalY());
	    menu->show();
	} else {
	    menu->hide();
	}
    } else if (23 <= x && x <= 112 && 76 <= y && y <= 111) {
	int button, newselection;

	button = ((x - 23) / 17) + 5 * ((y - 76) / 17);

	fprintf(stderr, "Button: %d\n", button);
	newselection = page * 10 + button;

	if (player->validpreset(newselection)) {

	    if (playing) {
		player->stop();
		playing = 0;
	    }

	    currentselection = newselection;

	    fprintf(stderr, "Button: %d %d\n", button, currentselection);
	    player->choosepreset(currentselection);

	    start();
	}


    } else if (121 <= x && x <= 138 && 76 <= y && 111) {
	if (y < 93) {
	    page++;
	    if (page > 9)
		page = 0;
	} else {
	    page--;
	    if (page < 0)
		page = 9;
	}
	presetview->setPixmap(QPixmap(numbers[page]));
    } else if (182 <= x && x <= 254 && 85 <= y && 102) {
	int action;

	action = (x - 182) / 14;
	switch (action) {
	case 0:
	    start();
	    break;
	case 1:
	    sig_stop = 1;
	    break;
	case 2:
	    break;		// Do nothing yet
	case 4:
	    player->mute();
	default:
	    break;
	}
    } else {
	fprintf(stderr, "%d %d %d\n", e->x(), e->y(), currentselection);
    }
}

void QtNewGui::mouseMoveEvent(QMouseEvent * e)
{
    int x, y;

    x = e->x();
    y = e->y();

    if (23 <= x && x <= 112 && 76 <= y && y <= 111) {
	int button;

	button = ((x - 23) / 17) + 5 * ((y - 76) / 17);
	status->setText(player->getname(page * 10 + button));
    } else {
	if (currentselection < 0) {
	    status->setText("");
	} else {
	    status->setText(player->getname(currentselection));
	}
    }

}

void QtNewGui::timerslot()
{


    if (sig_start) {
	if (player->start()) {
	    starttime = time(0);
	    sig_start = 0;
	    playing = 1;
	}
    }

    if (playing) {
	char *statusstr;
	int sec, min;
	int state;
	char timestr[10];
    }

    if (sig_stop) {
	player->stop();
	playing = 0;
	sig_stop = 0;
    }

}


void QtNewGui::setPlayer(Player * p)
{
    player = p;

    if (player->getautostart())
	sig_start = 1;
}

void QtNewGui::start()
{
    if (playing) {
	player->stop();
	playing = 0;
    }
    sig_start = 1;
}

void QtNewGui::do_menu(int itemid)
{
    switch (itemid) {
    	case 0: break;
    	case 2: break;
	case 4: rereadConfig();
		break;
	case 5: quit();
		break;
    }
}


void QtNewGui::rereadConfig()
{
    player->rereadConfig();
}


void QtNewGui::quit()
{
    if (timer->isActive())
	timer->stop();
    exit(0);
}
